@@ -190,3 +190,22 @@ class FlaviusOrderDecide(FlaviusBase):
     def __init__(self):
         super(FlaviusOrderDecide, self).__init__(search_url='', create_url='', update_url=conf.FLAVIUS_API_ORDER_DECIDE,
                                                  delete_url='')
+
+
+class FlaviusPaymentAdd(FlaviusBase):
+    """
+    Flaviusの支払明細を追加するAPI
+    """
+    def __init__(self):
+        super(FlaviusPaymentAdd, self).__init__(search_url='', create_url='', update_url=conf.FLAVIUS_API_PAYMENT_ADD,
+                                                delete_url='')
+
+
+class FlaviusPaymentComplete(FlaviusBase):
+    """
+    Flaviusの売上伝票を完了するAPI
+    """
+    def __init__(self):
+        super(FlaviusPaymentComplete, self).__init__(search_url='', create_url='',
+                                                     update_url=conf.FLAVIUS_API_PAYMENT_COMPLETE,
+                                                     delete_url='')
