@@ -78,6 +78,14 @@ class Settings:
     def FLAVIUS_API_PAGE_FETCH(self):
         return getattr(settings, "FLAVIUS_API_ORDER_DECIDE", 'api/pages.php')
 
+    @property
+    def FLAVIUS_API_PAYMENT_ADD(self):
+        return getattr(settings, "FLAVIUS_API_PAYMENT_ADD", 'api/payment_add.php')
+
+    @property
+    def FLAVIUS_API_PAYMENT_COMPLETE(self):
+        return getattr(settings, "FLAVIUS_API_PAYMENT_COMPLETE", 'api/payment_complete.php')
+
     @property
     def EXCLUDE_TAX(self):
         return getattr(settings, "EXCLUDE_TAX", '91100')
